==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/tools/images/Constants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.images;

import com.openexchange.config.ConfigurationService;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link Constants} - Provides constants for <i>com.openexchange.tools.images</i> package.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since 7.6.0
 */
public class Constants {

    /**
     * Initializes a new {@link Constants}.
     */
    private Constants() {
        super();
    }

    private static volatile Integer maxHeight;

    /**
     * The max. allowed height for image transformation.
     */
    public static int getMaxHeight() {
        Integer tmp = maxHeight;
        if (null == tmp) {
            synchronized (Constants.class) {
                tmp = maxHeight;
                if (null == tmp) {
                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
                    final int defaultMaxHeight = 4096;
                    if (null == service) {
                        return defaultMaxHeight;
                    }
                    tmp = Integer.valueOf(service.getIntProperty("com.openexchange.tools.images.maxHeight", defaultMaxHeight));
                    maxHeight = tmp;
                }
            }
        }
        return tmp.intValue();
    }

    private static volatile Integer maxWidth;

    /**
     * The max. allowed width for image transformation.
     */
    public static int getMaxWidth() {
        Integer tmp = maxWidth;
        if (null == tmp) {
            synchronized (Constants.class) {
                tmp = maxWidth;
                if (null == tmp) {
                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
                    final int defaultMaxWidth = 4096;
                    if (null == service) {
                        return defaultMaxWidth;
                    }
                    tmp = Integer.valueOf(service.getIntProperty("com.openexchange.tools.images.maxWidth", defaultMaxWidth));
                    maxWidth = tmp;
                }
            }
        }
        return tmp.intValue();
    }

}

==> open-xchange-core_7.6.0.orig.tar.bz2: open-xchange-core-7.6.0/com.openexchange.server/src/com/openexchange/tools/images/Constants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.tools.images;

import java.util.Map;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.Reloadable;
import com.openexchange.server.reloadable.GenericReloadable;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link Constants} - Provides constants for <i>com.openexchange.tools.images</i> package.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since 7.6.0
 */
public class Constants {

    /**
     * Initializes a new {@link Constants}.
     */
    private Constants() {
        super();
    }

    static {
        GenericReloadable.getInstance().addReloadable(new Reloadable() {

            @Override
            public void reloadConfiguration(final ConfigurationService configService) {
                maxHeight = null;
                maxWidth = null;
            }

            @Override
            public Map<String, String[]> getConfigFileNames() {
                return null;
            }
        });
    }

    private static volatile Integer maxHeight;

    /**
     * The max. allowed height for image transformation.
     */
    public static int getMaxHeight() {
        Integer tmp = maxHeight;
        if (null == tmp) {
            synchronized (Constants.class) {
                tmp = maxHeight;
                if (null == tmp) {
                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
                    final int defaultMaxHeight = 4096;
                    if (null == service) {
                        return defaultMaxHeight;
                    }
                    tmp = Integer.valueOf(service.getIntProperty("com.openexchange.tools.images.maxHeight", defaultMaxHeight));
                    maxHeight = tmp;
                }
            }
        }
        return tmp.intValue();
    }

    private static volatile Integer maxWidth;

    /**
     * The max. allowed width for image transformation.
     */
    public static int getMaxWidth() {
        Integer tmp = maxWidth;
        if (null == tmp) {
            synchronized (Constants.class) {
                tmp = maxWidth;
                if (null == tmp) {
                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
                    final int defaultMaxWidth = 4096;
                    if (null == service) {
                        return defaultMaxWidth;
                    }
                    tmp = Integer.valueOf(service.getIntProperty("com.openexchange.tools.images.maxWidth", defaultMaxWidth));
                    maxWidth = tmp;
                }
            }
        }
        return tmp.intValue();
    }

}
